# tiangong

> TianGong — The Celestial Forge for AI Agents. An open-source AI Agent cultivation platform.

⚒️ Part of the [TianGong (天工)](https://github.com/JinNing6/TianGong) ecosystem.

## Status

🔵 **Planning** — This package is under active development. Stay tuned!

## About TianGong

**天工 TianGong** is an open-source AI Agent cultivation platform where developers create, refine, and share their AI Agents.

> 我命由我不由天。
> *My fate is mine, not heaven's.*

## Links

- [GitHub](https://github.com/JinNing6/TianGong)
- [Documentation](https://github.com/JinNing6/TianGong#readme)

## License

MIT
